package com.ruoyi.post.service.impl;

import java.util.List;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.post.domain.PostCollection;
import org.springframework.stereotype.Service;
import com.ruoyi.post.mapper.PostSeriesMapper;
import com.ruoyi.post.domain.PostSeries;
import com.ruoyi.post.service.IPostSeriesService;
import javax.annotation.Resource;

/**
 * 邮贝套系信息; 
 * 
 * @author huianan
 * @date 2023-02-11
 */
@Service
public class PostSeriesServiceImpl implements IPostSeriesService 
{
    @Resource
    private PostSeriesMapper postSeriesMapper;

    /**
     * 查询邮贝套系信息; 
     * 
     * @param seriesId 邮贝套系信息; 主键
     * @return 邮贝套系信息; 
     */
    @Override
    public PostSeries selectPostSeriesBySeriesId(Long seriesId)
    {
        return postSeriesMapper.selectPostSeriesBySeriesId(seriesId);
    }

    /**
     * 查询邮贝套系信息; 列表
     * 
     * @param postSeries 邮贝套系信息; 
     * @return 邮贝套系信息; 
     */
    @Override
    public List<PostSeries> selectPostSeriesList(PostSeries postSeries)
    {
        return postSeriesMapper.selectPostSeriesList(postSeries);
    }

    /**
     * 查询邮贝在售套系信息; 列表
     *
     * @param postSeries 邮贝套系信息;
     * @return 邮贝套系信息;
     */
    @Override
    public List<PostSeries> selectPostSeriesSale(PostSeries postSeries) {
        return postSeriesMapper.selectPostSeriesSale(postSeries);
    }

    /**
     * 查询邮贝预售套系信息; 列表
     *
     * @param postSeries 邮贝套系信息;
     * @return 邮贝套系信息;
     */
    @Override
    public List<PostSeries> selectPostSeriesPreSale(PostSeries postSeries) {
        return postSeriesMapper.selectPostSeriesPreSale(postSeries);
    }

    /**
     * 查询邮贝过期套系信息; 列表
     *
     * @param postSeries 邮贝套系信息;
     * @return 邮贝套系信息;
     */
    @Override
    public List<PostSeries> selectPostSeriesOverdue(PostSeries postSeries) {
        return postSeriesMapper.selectPostSeriesOverdue(postSeries);
    }

    /**
     * 新增邮贝套系信息; 
     * 
     * @param postSeries 邮贝套系信息; 
     * @return 结果
     */
    @Override
    public int insertPostSeries(PostSeries postSeries)
    {
        postSeries.setCreateTime(DateUtils.getNowDate());
        return postSeriesMapper.insertPostSeries(postSeries);
    }

    /**
     * 修改邮贝套系信息; 
     * 
     * @param postSeries 邮贝套系信息; 
     * @return 结果
     */
    @Override
    public int updatePostSeries(PostSeries postSeries)
    {
        postSeries.setUpdateTime(DateUtils.getNowDate());
        return postSeriesMapper.updatePostSeries(postSeries);
    }

    /**
     * 批量删除邮贝套系信息; 
     * 
     * @param seriesIds 需要删除的邮贝套系信息; 主键
     * @return 结果
     */
    @Override
    public int deletePostSeriesBySeriesIds(Long[] seriesIds)
    {
        return postSeriesMapper.deletePostSeriesBySeriesIds(seriesIds);
    }

    /**
     * 删除邮贝套系信息; 信息
     * 
     * @param seriesId 邮贝套系信息; 主键
     * @return 结果
     */
    @Override
    public int deletePostSeriesBySeriesId(Long seriesId)
    {
        return postSeriesMapper.deletePostSeriesBySeriesId(seriesId);
    }

    @Override
    public String checkSeriesNameUnique(PostSeries postSeries) {
        Long SeriesId = StringUtils.isNull(postSeries.getSeriesId()) ? -1l : postSeries.getSeriesId();
        PostSeries info = postSeriesMapper.checkSeriesNameUnique(postSeries.getSeriesName());
        if (StringUtils.isNotNull(info)&&info.getSeriesId().longValue()!= SeriesId.longValue()) {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }
}
